From foo@baz Wed Jun 22 08:12:42 2005
Date: Wed, 22 Jun 2005 16:09:05 -0700
From: Greg Kroah-Hartman <gregkh@suse.de>
To: Greg KH <gregkh@suse.de>
Subject: driver core: change bus_rescan_devices to return void

No one was looking at the return value of bus_rescan_devices, and it
really wasn't anything that anyone in the kernel would ever care about.
So change it which enabled some counting code to be removed also.

Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/base/bus.c     |   27 +++++++++------------------
 include/linux/device.h |    2 +-
 2 files changed, 10 insertions(+), 19 deletions(-)

--- gregkh-2.6.orig/drivers/base/bus.c	2005-06-22 23:29:49.000000000 -0700
+++ gregkh-2.6/drivers/base/bus.c	2005-06-22 23:29:50.000000000 -0700
@@ -463,31 +463,22 @@
 /* Helper for bus_rescan_devices's iter */
 static int bus_rescan_devices_helper(struct device *dev, void *data)
 {
-	int *count = data;
-
-	if (!dev->driver && (device_attach(dev) > 0))
-		(*count)++;
-
+	if (!dev->driver)
+		device_attach(dev);
 	return 0;
 }
 
-
 /**
- *	bus_rescan_devices - rescan devices on the bus for possible drivers
- *	@bus:	the bus to scan.
+ * bus_rescan_devices - rescan devices on the bus for possible drivers
+ * @bus: the bus to scan.
  *
- *	This function will look for devices on the bus with no driver
- *	attached and rescan it against existing drivers to see if it
- *	matches any. Calls device_attach(). Returns the number of devices
- *	that were sucessfully bound to a driver.
+ * This function will look for devices on the bus with no driver
+ * attached and rescan it against existing drivers to see if it matches
+ * any by calling device_attach() for the unbound devices.
  */
-int bus_rescan_devices(struct bus_type * bus)
+void bus_rescan_devices(struct bus_type * bus)
 {
-	int count = 0;
-
-	bus_for_each_dev(bus, NULL, &count, bus_rescan_devices_helper);
-
-	return count;
+	bus_for_each_dev(bus, NULL, NULL, bus_rescan_devices_helper);
 }
 
 
--- gregkh-2.6.orig/include/linux/device.h	2005-06-22 23:29:49.000000000 -0700
+++ gregkh-2.6/include/linux/device.h	2005-06-22 23:29:50.000000000 -0700
@@ -69,7 +69,7 @@
 extern int bus_register(struct bus_type * bus);
 extern void bus_unregister(struct bus_type * bus);
 
-extern int bus_rescan_devices(struct bus_type * bus);
+extern void bus_rescan_devices(struct bus_type * bus);
 
 extern struct bus_type * get_bus(struct bus_type * bus);
 extern void put_bus(struct bus_type * bus);
